confint.glmb: Credible Intervals for Model Parameters

View source: R/confint.glmb.R

confint.glmbR Documentation

Credible Intervals for Model Parameters

Description

Computes Bayesian credible intervals for model parameters from posterior draws. Intervals are constructed as quantiles of the posterior distribution, following the standard approach for posterior summaries \insertCiteGelman2013glmbayes.

Usage

## S3 method for class 'glmb'
confint(object, parm, level = 0.95, ...)

Arguments

object

a fitted model object of class "glmb". Typically the result of a call to glmb.

parm

a specification (not yet implemented) of which parameters are to be given credible sets, either a vector of numbers or a vector of names. If missing, all parameters are considered.

level

the credible interval required.

...

additional argument(s) for methods.

Value

A matrix (or vector) with columns giving lower and upper credible limits for each parameter. These will be labeled (1-level)/2 and 1-(1-level)/2 in \

References

\insertAllCited

See Also

summary.glmb, vcov.glmb, glmb, glmbayes-package; rglmb, rlmb, lmb; confint for classical confidence intervals

Examples


## ----dobson-------------------------------------------------------------------
## Dobson (1990) Page 93: Randomized Controlled Trial :
counts <- c(18, 17, 15, 20, 10, 20, 25, 13, 12)
outcome <- gl(3, 1, 9)
treatment <- gl(3, 3)

ps <- Prior_Setup(counts ~ outcome + treatment, family = poisson())
## Call to glmb
glmb.D93 <- glmb(
  n = 1000,
  counts ~ outcome + treatment,
  family = poisson(),
  pfamily = dNormal(mu = ps$mu, Sigma = ps$Sigma)
)
## ----glmb confint-------------------------------------------------------------
confint(glmb.D93)

glmbayes documentation built on Aug. 5, 2026, 1:07 a.m.

Related to confint.glmb in glmbayes...