formula.summary.rglmb: Model Formulae

View source: R/formula.summary.rglmb.R

formula.summary.rglmbR Documentation

Model Formulae

Description

This function is a method function for the "summary.rglmb" class used to Extract a formulae for the objective and the family

Usage

## S3 method for class 'summary.rglmb'
formula(x, ...)

Arguments

x

an object of class summary.rglmb, typically the result of a call to summary.rglmb

...

further arguments to or from other methods

Value

The function returns model formulae

See Also

rglmb, summary.rglmb; glmb, glmbayes-package; rlmb, lmb; formula.


glmbayes documentation built on Aug. 5, 2026, 1:07 a.m.

Related to formula.summary.rglmb in glmbayes...