logLik.glmb: Extract Log-Likelihood

View source: R/logLik.glmb.R

logLik.glmbR Documentation

Extract Log-Likelihood

Description

This function is a method function for the "glmb" class used to Extract the log-Likelihood from a Bayesian Generalized Linear Model.

Usage

## S3 method for class 'glmb'
logLik(object, ...)

Arguments

object

an object of class glmb, typically the result of a call to glmb

...

further arguments to or from other methods

Value

The function returns a vector, logLikout with the estimated log-likelihood for each draw.

See Also

glmb, glmbayes-package; rglmb, rlmb, lmb; logLik.

Examples

## ----dobson-------------------------------------------------------------------
## Dobson (1990) Page 93: Randomized Controlled Trial :
counts <- c(18, 17, 15, 20, 10, 20, 25, 13, 12)
outcome <- gl(3, 1, 9)
treatment <- gl(3, 3)

ps <- Prior_Setup(counts ~ outcome + treatment, family = poisson())
## Call to glmb
glmb.D93 <- glmb(
  n = 1000,
  counts ~ outcome + treatment,
  family = poisson(),
  pfamily = dNormal(mu = ps$mu, Sigma = ps$Sigma)
)
## ----glmb logLik-------------------------------------------------------------
colMeans(logLik(glmb.D93))

glmbayes documentation built on Aug. 5, 2026, 1:07 a.m.

Related to logLik.glmb in glmbayes...