vcov.glmb: Calculate Variance-Covariance Matrix for a Fitted Model...

View source: R/vcov.glmb.R

vcov.glmbR Documentation

Calculate Variance-Covariance Matrix for a Fitted Model Object

Description

Returns the posterior variance-covariance matrix of the regression coefficients from a fitted Bayesian GLM object \insertCiteGelman2013glmbayes.

Usage

## S3 method for class 'glmb'
vcov(object, ...)

Arguments

object

fitted model object, typically the result of a call to glmb.

...

additional arguments for method functions.

Value

A matrix of estimated covariances between the parameter estimates in the linear or non-linear predictor of the model. This should have row and column names corresponding to the parameter names given by the coef method.

References

\insertAllCited

See Also

confint.glmb, summary.glmb, glmb, glmbayes-package; rglmb, rlmb, lmb; vcov

Examples

## ----dobson-------------------------------------------------------------------
## Dobson (1990) Page 93: Randomized Controlled Trial :
counts <- c(18, 17, 15, 20, 10, 20, 25, 13, 12)
outcome <- gl(3, 1, 9)
treatment <- gl(3, 3)

ps <- Prior_Setup(counts ~ outcome + treatment, family = poisson())
## Call to glmb
glmb.D93 <- glmb(
  n = 1000,
  counts ~ outcome + treatment,
  family = poisson(),
  pfamily = dNormal(mu = ps$mu, Sigma = ps$Sigma)
)

## ----glmb vcov----------------------------------------------------------------
vcov(glmb.D93)

glmbayes documentation built on Aug. 5, 2026, 1:07 a.m.

Related to vcov.glmb in glmbayes...