| AMI | R Documentation |
Data with information on 17 overdoses of the drug amitriptyline
data(AMI)
This data frame contains the following columns:
TOTtotal TCAD plasma level
AMIamount of amitriptyline present in the TCAD plasma level
GENgender (male = 0, female = 1)
AMTamount of drug taken at time of overdose
PRPR wave measurement
DIAPdiastolic blood pressure
QRSQRS wave measurement
Each row is one overdose episode. Variables include total tricyclic antidepressant level, amitriptyline component, gender, reported amount ingested, and ECG-related measures (PR interval, QRS duration, diastolic blood pressure). The dataset is used in package examples for binomial and related regression; see \insertCiteDobson1990glmbayes for analogous generalized linear modelling of clinical outcomes.
############################### Start of AMI dataset example ####################
data(AMI)
summary(AMI)
###############################################################################
## End of AMI dataset example
###############################################################################
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.