View source: R/formula.summary.rglmb.R
| formula.summary.rglmb | R Documentation |
This function is a method function for the "summary.rglmb" class used to
Extract a formulae for the objective and the family
## S3 method for class 'summary.rglmb'
formula(x, ...)
x |
an object of class |
... |
further arguments to or from other methods |
The function returns model formulae
rglmb, summary.rglmb; glmb, glmbayes-package;
rlmb, lmb; formula.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.