| vcov.glmb | R Documentation |
Returns the posterior variance-covariance matrix of the regression coefficients from a fitted Bayesian GLM object \insertCiteGelman2013glmbayes.
## S3 method for class 'glmb'
vcov(object, ...)
object |
fitted model object, typically the result of a call to |
... |
additional arguments for method functions. |
A matrix of estimated covariances between the parameter estimates
in the linear or non-linear predictor of the model. This should have
row and column names corresponding to the parameter names given by the
coef method.
confint.glmb, summary.glmb, glmb,
glmbayes-package; rglmb, rlmb, lmb;
vcov
## ----dobson-------------------------------------------------------------------
## Dobson (1990) Page 93: Randomized Controlled Trial :
counts <- c(18, 17, 15, 20, 10, 20, 25, 13, 12)
outcome <- gl(3, 1, 9)
treatment <- gl(3, 3)
ps <- Prior_Setup(counts ~ outcome + treatment, family = poisson())
## Call to glmb
glmb.D93 <- glmb(
n = 1000,
counts ~ outcome + treatment,
family = poisson(),
pfamily = dNormal(mu = ps$mu, Sigma = ps$Sigma)
)
## ----glmb vcov----------------------------------------------------------------
vcov(glmb.D93)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.